package com.yanzhu.jh.trouble.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.system.service.ISysDeptService;
import com.yanzhu.jh.trouble.domain.SmzSspAuditinfo;
import com.yanzhu.jh.trouble.service.ISmzSspAuditinfoService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.trouble.domain.SmzSspProblemmodify;
import com.yanzhu.jh.trouble.service.ISmzSspProblemmodifyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 质量整改Controller
 * 
 * @author JiangYuQi
 * @date 2023-07-28
 */
@RestController
@RequestMapping("/trouble/sspProblemmodify")
public class SmzSspProblemmodifyController extends BaseController
{
    @Autowired
    private ISysDeptService sysDeptService;

    @Autowired
    private ISmzSspAuditinfoService smzSspAuditinfoService;

    @Autowired
    private ISmzSspProblemmodifyService smzSspProblemmodifyService;

    /**
     * 查询质量整改列表
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:list')")
    @GetMapping("/list")
    public TableDataInfo list(SmzSspProblemmodify smzSspProblemmodify)
    {
        startPage();
        smzSspProblemmodify.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(smzSspProblemmodify.getNowRole())){
            smzSspProblemmodify.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            smzSspProblemmodify.setNowDept(Convert.toStr(getDeptId()));
        }
        smzSspProblemmodify.setNowUser(getLoginUser().getUsername());
        List<SmzSspProblemmodify> list = smzSspProblemmodifyService.selectSmzSspProblemmodifyList(smzSspProblemmodify);
        return getDataTable(list);
    }

    /**
     * 统计随手拍数量
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:query')")
    @GetMapping("/findGroupCount")
    public AjaxResult findGroupCount(SmzSspProblemmodify smzSspProblemmodify)
    {
        smzSspProblemmodify.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(smzSspProblemmodify.getNowRole())){
            smzSspProblemmodify.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            smzSspProblemmodify.setNowDept(Convert.toStr(getDeptId()));
        }
        smzSspProblemmodify.setNowUser(getLoginUser().getUsername());
        return success(smzSspProblemmodifyService.findProblemmodifyGroupByCheckState(smzSspProblemmodify));
    }

    /**
     * 导出质量整改列表
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:export')")
    @Log(title = "质量整改", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SmzSspProblemmodify smzSspProblemmodify)
    {
        smzSspProblemmodify.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(smzSspProblemmodify.getNowRole())){
            smzSspProblemmodify.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            smzSspProblemmodify.setNowDept(Convert.toStr(getDeptId()));
        }
        smzSspProblemmodify.setNowUser(getLoginUser().getUsername());
        List<SmzSspProblemmodify> list = smzSspProblemmodifyService.selectSmzSspProblemmodifyList(smzSspProblemmodify);
        ExcelUtil<SmzSspProblemmodify> util = new ExcelUtil<SmzSspProblemmodify>(SmzSspProblemmodify.class);
        util.exportExcel(response, list, "质量整改数据");
    }

    /**
     * 获取质量整改详细信息
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(smzSspProblemmodifyService.selectSmzSspProblemmodifyById(id));
    }

    /**
     * 新增质量整改
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:add')")
    @Log(title = "质量整改", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SmzSspProblemmodify smzSspProblemmodify)
    {
        return toAjax(smzSspProblemmodifyService.insertSmzSspProblemmodify(smzSspProblemmodify));
    }

    /**
     * 修改质量整改
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:edit')")
    @Log(title = "质量整改", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SmzSspProblemmodify smzSspProblemmodify)
    {
        return toAjax(smzSspProblemmodifyService.updateSmzSspProblemmodify(smzSspProblemmodify));
    }

    /**
     * 删除质量整改
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:remove')")
    @Log(title = "质量整改", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(smzSspProblemmodifyService.deleteSmzSspProblemmodifyByIds(ids));
    }

    /**
     * 获取质量整改详细信息
     */
    @PreAuthorize("@ss.hasPermi('trouble:sspProblemmodify:query')")
    @GetMapping("/auditinfoList")
    public TableDataInfo listSmzSspAuditinfo(SmzSspAuditinfo smzSspAuditinfo)
    {
        return getDataTable(smzSspAuditinfoService.selectSmzSspAuditinfoList(smzSspAuditinfo));
    }
}
